@@ -17,7 +17,7 @@
 
 #include "portab.h"
 
-static char UNUSED id[] = "$Id: channel.c,v 1.56 2006/07/24 22:54:09 alex Exp $";
+static char UNUSED id[] = "$Id: channel.c,v 1.56.2.3 2007/04/03 22:08:52 fw Exp $";
 
 #include "imp.h"
 #include <assert.h>
@@ -70,6 +70,22 @@ Channel_Init( void )
 } /* Channel_Init */
 
 
+GLOBAL struct list_head *
+Channel_GetListBans(CHANNEL *c)
+{
+	assert(c != NULL);
+	return &c->list_bans;
+}
+
+
+GLOBAL struct list_head *
+Channel_GetListInvites(CHANNEL *c)
+{
+	assert(c != NULL);
+	return &c->list_invites;
+}
+
+
 GLOBAL void
 Channel_InitPredefined( void )
 {
@@ -114,7 +130,10 @@ Channel_InitPredefined( void )
 			c = Conf_Channel[i].modes;
 			while (*c)
 				Channel_ModeAdd(chan, *c++);
-		
+
+			Channel_SetKey(chan, Conf_Channel[i].key);
+			Channel_SetMaxUsers(chan, Conf_Channel[i].maxusers);
+
 			Log(LOG_INFO, "Created pre-defined channel \"%s\".",
 							Conf_Channel[i].name );
 		}
@@ -129,7 +148,7 @@ Channel_Exit( void )
 {
 	CHANNEL *c, *c_next;
 	CL2CHAN *cl2chan, *cl2chan_next;
-	
+
 	/* Channel-Strukturen freigeben */
 	c = My_Channels;
 	while( c )
@@ -173,7 +192,7 @@ Channel_Join( CLIENT *Client, char *Name )
 	{
 		/* Gibt es noch nicht? Dann neu anlegen: */
 		chan = Channel_Create( Name );
-		if( ! chan ) return false;
+		if (!chan) return false;
 	}
 
 	/* User dem Channel hinzufuegen */
@@ -214,7 +233,6 @@ Channel_Kick( CLIENT *Client, CLIENT *Origin, char *Name, char *Reason )
 	assert( Name != NULL );
 	assert( Reason != NULL );
 
-	/* Channel suchen */
 	chan = Channel_Search( Name );
 	if( ! chan )
 	{
@@ -266,11 +284,11 @@ Channel_Quit( CLIENT *Client, char *Reason )
 } /* Channel_Quit */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Channel_Count( void )
 {
 	CHANNEL *c;
-	long count = 0;
+	unsigned long count = 0;
 	
 	c = My_Channels;
 	while( c )
@@ -282,11 +300,11 @@ Channel_Count( void )
 } /* Channel_Count */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Channel_MemberCount( CHANNEL *Chan )
 {
 	CL2CHAN *cl2chan;
-	long count = 0;
+	unsigned long count = 0;
 
 	assert( Chan != NULL );
 
@@ -321,27 +339,9 @@ Channel_CountForUser( CLIENT *Client )
 } /* Channel_CountForUser */
 
 
-GLOBAL int
-Channel_PCount( void )
-{
-	/* Count the number of persistent (mode 'P') channels */
 
-	CHANNEL *chan;
-	int count = 0;
-
-	chan = My_Channels;
-	while( chan )
-	{
-		if( strchr( chan->modes, 'P' )) count++;
-		chan = chan->next;
-	}
-
-	return count;
-} /* Channel_PCount */
-
-
-GLOBAL char *
-Channel_Name( CHANNEL *Chan )
+GLOBAL const char *
+Channel_Name( const CHANNEL *Chan )
 {
 	assert( Chan != NULL );
 	return Chan->name;
@@ -364,7 +364,7 @@ Channel_Key( CHANNEL *Chan )
 } /* Channel_Key */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Channel_MaxUsers( CHANNEL *Chan )
 {
 	assert( Chan != NULL );
@@ -463,25 +463,13 @@ Channel_GetChannel( CL2CHAN *Cl2Chan )
 
 
 GLOBAL bool
-Channel_IsValidName( char *Name )
+Channel_IsValidName( const char *Name )
 {
-	/* Pruefen, ob Name als Channelname gueltig */
-
-	char *ptr, badchars[10];
-	
 	assert( Name != NULL );
 
 	if(( Name[0] != '#' ) || ( strlen( Name ) >= CHANNEL_NAME_LEN )) return false;
 
-	ptr = Name;
-	strcpy( badchars, " ,:\007" );
-	while( *ptr )
-	{
-		if( strchr( badchars, *ptr )) return false;
-		ptr++;
-	}
-	
-	return true;
+	return Name[strcspn(Name, " ,:\007")] == 0;
 } /* Channel_IsValidName */
 
 
@@ -548,7 +536,7 @@ Channel_UserModeAdd( CHANNEL *Chan, CLIENT *Client, char Mode )
 
 	cl2chan = Get_Cl2Chan( Chan, Client );
 	assert( cl2chan != NULL );
-	
+
 	x[0] = Mode; x[1] = '\0';
 	if( ! strchr( cl2chan->modes, x[0] ))
 	{
@@ -594,7 +582,7 @@ GLOBAL char *
 Channel_UserModes( CHANNEL *Chan, CLIENT *Client )
 {
 	/* return Users' Channel-Modes */
-	
+
 	CL2CHAN *cl2chan;
 
 	assert( Chan != NULL );
@@ -614,9 +602,7 @@ Channel_IsMemberOf( CHANNEL *Chan, CLIENT *Client )
 
 	assert( Chan != NULL );
 	assert( Client != NULL );
-
-	if( Get_Cl2Chan( Chan, Client )) return true;
-	else return false;
+	return Get_Cl2Chan(Chan, Client);
 } /* Channel_IsMemberOf */
 
 
@@ -661,12 +647,9 @@ Channel_SetTopic(CHANNEL *Chan, CLIENT *Client, char *Topic)
 	if (len < array_bytes(&Chan->topic))
 		array_free(&Chan->topic);
 
-	if (!array_copyb(&Chan->topic, Topic, len))
+	if (len >= COMMAND_LEN || !array_copyb(&Chan->topic, Topic, len+1))
 		Log(LOG_WARNING, "could not set new Topic \"%s\" on %s: %s",
 					Topic, Chan->name, strerror(errno));
-
-	array_cat0(&Chan->topic);
-
 #ifndef STRICT_RFC
 	Chan->topic_time = time(NULL);
 	if (Client != NULL && Client_Type(Client) != CLIENT_SERVER)
@@ -698,17 +681,17 @@ Channel_SetKey( CHANNEL *Chan, char *Key )
 	assert( Key != NULL );
 
 	strlcpy( Chan->key, Key, sizeof( Chan->key ));
-	Log( LOG_DEBUG, "Channel %s: Key is now \"%s\".", Chan->name, Chan->key );
+	LogDebug("Channel %s: Key is now \"%s\".", Chan->name, Chan->key );
 } /* Channel_SetKey */
 
 
 GLOBAL void
-Channel_SetMaxUsers( CHANNEL *Chan, long Count )
+Channel_SetMaxUsers(CHANNEL *Chan, unsigned long Count)
 {
 	assert( Chan != NULL );
 
 	Chan->maxusers = Count;
-	Log( LOG_DEBUG, "Channel %s: Member limit is now %ld.", Chan->name, Chan->maxusers );
+	LogDebug("Channel %s: Member limit is now %lu.", Chan->name, Chan->maxusers );
 } /* Channel_SetMaxUsers */
 
 
@@ -730,9 +713,9 @@ Channel_Write( CHANNEL *Chan, CLIENT *From, CLIENT *Client, char *Text )
 	ok = true;
 	if( strchr( Channel_Modes( Chan ), 'n' ) && ( ! is_member )) ok = false;
 	if( strchr( Channel_Modes( Chan ), 'm' ) && ( ! is_op ) && ( ! has_voice )) ok = false;
-	
+
 	/* Is the client banned? */
-	if( Lists_CheckBanned( From, Chan ))
+	if( Lists_Check(&Chan->list_bans, From))
 	{
 		/* Client is banned, but is he channel operator or has voice? */
 		if(( ! has_voice ) && ( ! is_op )) ok = false;
@@ -753,7 +736,7 @@ Channel_Create( char *Name )
 	CHANNEL *c;
 
 	assert( Name != NULL );
-	
+
 	c = (CHANNEL *)malloc( sizeof( CHANNEL ));
 	if( ! c )
 	{
@@ -765,9 +748,7 @@ Channel_Create( char *Name )
 	c->hash = Hash( c->name );
 	c->next = My_Channels;
 	My_Channels = c;
-#ifdef DEBUG	
-	Log( LOG_DEBUG, "Created new channel structure for \"%s\".", Name );
-#endif
+	LogDebug("Created new channel structure for \"%s\".", Name);
 	return c;
 } /* Channel_Create */
 
@@ -851,25 +832,42 @@ Remove_Client( int Type, CHANNEL *Chan, CLIENT *Client, CLIENT *Origin, char *Re
 	switch( Type )
 	{
 		case REMOVE_QUIT:
-			/* QUIT: andere Server wurden bereits informiert, vgl. Client_Destroy();
-			 * hier also "nur" noch alle User in betroffenen Channeln infomieren */
+			/* QUIT: other servers have already been notified, see Client_Destroy();
+			 * so only inform other clients in same channel. */
 			assert( InformServer == false );
-			Log( LOG_DEBUG, "User \"%s\" left channel \"%s\" (%s).", Client_Mask( Client ), c->name, Reason );
+			LogDebug("User \"%s\" left channel \"%s\" (%s).",
+					Client_Mask( Client ), c->name, Reason );
 			break;
 		case REMOVE_KICK:
-			/* User wurde geKICKed: ggf. andere Server sowie alle betroffenen User
-			 * im entsprechenden Channel informieren */
-			if( InformServer ) IRC_WriteStrServersPrefix( Client_NextHop( Origin ), Origin, "KICK %s %s :%s", c->name, Client_ID( Client ), Reason );
-			IRC_WriteStrChannelPrefix( Client, c, Origin, false, "KICK %s %s :%s", c->name, Client_ID( Client ), Reason );
-			if(( Client_Conn( Client ) > NONE ) && ( Client_Type( Client ) == CLIENT_USER )) IRC_WriteStrClientPrefix( Client, Origin, "KICK %s %s :%s", c->name, Client_ID( Client ), Reason );
-			Log( LOG_DEBUG, "User \"%s\" has been kicked of \"%s\" by \"%s\": %s.", Client_Mask( Client ), c->name, Client_ID( Origin ), Reason );
+			/* User was KICKed: inform other servers and all users in channel */
+			if( InformServer )
+				IRC_WriteStrServersPrefix( Client_NextHop( Origin ),
+					Origin, "KICK %s %s :%s", c->name, Client_ID( Client ), Reason);
+			IRC_WriteStrChannelPrefix(Client, c, Origin, false, "KICK %s %s :%s",
+							c->name, Client_ID( Client ), Reason );
+			if ((Client_Conn(Client) > NONE) &&
+					(Client_Type(Client) == CLIENT_USER))
+			{
+				IRC_WriteStrClientPrefix(Client, Origin, "KICK %s %s :%s",
+								c->name, Client_ID( Client ), Reason);
+			}
+			LogDebug("User \"%s\" has been kicked of \"%s\" by \"%s\": %s.",
+				Client_Mask( Client ), c->name, Client_ID(Origin), Reason);
 			break;
-		default:
-			/* PART */
-			if( InformServer ) IRC_WriteStrServersPrefix( Origin, Client, "PART %s :%s", c->name, Reason );
-			IRC_WriteStrChannelPrefix( Origin, c, Client, false, "PART %s :%s", c->name, Reason );
-			if(( Client_Conn( Origin ) > NONE ) && ( Client_Type( Origin ) == CLIENT_USER )) IRC_WriteStrClientPrefix( Origin, Client, "PART %s :%s", c->name, Reason );
-			Log( LOG_DEBUG, "User \"%s\" left channel \"%s\" (%s).", Client_Mask( Client ), c->name, Reason );
+		default: /* PART */
+			if (InformServer)
+				IRC_WriteStrServersPrefix(Origin, Client, "PART %s :%s", c->name, Reason);
+
+			IRC_WriteStrChannelPrefix(Origin, c, Client, false, "PART %s :%s",
+									c->name, Reason);
+
+			if ((Client_Conn(Origin) > NONE) &&
+					(Client_Type(Origin) == CLIENT_USER))
+			{
+				IRC_WriteStrClientPrefix( Origin, Client, "PART %s :%s", c->name, Reason);
+				LogDebug("User \"%s\" left channel \"%s\" (%s).",
+					Client_Mask(Client), c->name, Reason);
+			}
 	}
 
 	/* Wenn Channel nun leer und nicht pre-defined: loeschen */
@@ -882,6 +880,68 @@ Remove_Client( int Type, CHANNEL *Chan, CLIENT *Client, CLIENT *Origin, char *Re
 } /* Remove_Client */
 
 
+GLOBAL bool
+Channel_AddBan(CHANNEL *c, const char *mask )
+{
+	struct list_head *h = Channel_GetListBans(c);
+	return Lists_Add(h, mask, false);
+}
+
+
+GLOBAL bool
+Channel_AddInvite(CHANNEL *c, const char *mask, bool onlyonce)
+{
+	struct list_head *h = Channel_GetListInvites(c);
+	return Lists_Add(h, mask, onlyonce);
+}
+
+
+static bool
+ShowInvitesBans(struct list_head *head, CLIENT *Client, CHANNEL *Channel, bool invite)
+{
+	struct list_elem *e;
+	char *msg = invite ? RPL_INVITELIST_MSG : RPL_BANLIST_MSG;
+	char *msg_end;
+
+	assert( Client != NULL );
+	assert( Channel != NULL );
+
+	e = Lists_GetFirst(head);
+	while (e) {
+		if( ! IRC_WriteStrClient( Client, msg, Client_ID( Client ),
+				Channel_Name( Channel ), Lists_GetMask(e) )) return DISCONNECTED;
+		e = Lists_GetNext(e);
+	}
+
+	msg_end = invite ? RPL_ENDOFINVITELIST_MSG : RPL_ENDOFBANLIST_MSG;
+	return IRC_WriteStrClient( Client, msg_end, Client_ID( Client ), Channel_Name( Channel ));
+}
+
+
+GLOBAL bool
+Channel_ShowBans( CLIENT *Client, CHANNEL *Channel )
+{
+	struct list_head *h;
+
+	assert( Channel != NULL );
+
+	h = Channel_GetListBans(Channel);
+	return ShowInvitesBans(h, Client, Channel, false);
+}
+
+
+GLOBAL bool
+Channel_ShowInvites( CLIENT *Client, CHANNEL *Channel )
+{
+	struct list_head *h;
+
+	assert( Channel != NULL );
+
+	h = Channel_GetListInvites(Channel);
+	return ShowInvitesBans(h, Client, Channel, true);
+}
+
+
 static CL2CHAN *
 Get_First_Cl2Chan( CLIENT *Client, CHANNEL *Chan )
 {
@@ -911,7 +971,7 @@ static bool
 Delete_Channel( CHANNEL *Chan )
 {
 	/* Channel-Struktur loeschen */
-	
+
 	CHANNEL *chan, *last_chan;
 
 	last_chan = NULL;
@@ -927,13 +987,14 @@ Delete_Channel( CHANNEL *Chan )
 	Log( LOG_DEBUG, "Freed channel structure for \"%s\".", Chan->name );
 
 	/* Invite- und Ban-Lists aufraeumen */
-	Lists_DeleteChannel( chan );
+	Lists_Free( &chan->list_bans );
+	Lists_Free( &chan->list_invites );
 
 	/* Neu verketten und freigeben */
 	if( last_chan ) last_chan->next = chan->next;
 	else My_Channels = chan->next;
 	free( chan );
-		
+
 	return true;
 } /* Delete_Channel */
 
