@@ -8,7 +8,7 @@
  * (at your option) any later version.
  * Please read the file COPYING, README and AUTHORS for more information.
  *
- * $Id: channel.h,v 1.29 2005/09/02 12:50:25 alex Exp $
+ * $Id: channel.h,v 1.29.2.2 2007/04/03 20:23:31 fw Exp $
  *
  * Channel management (header)
  */
@@ -20,6 +20,7 @@
 
 #if defined(__channel_c__) | defined(S_SPLINT_S)
 
+#include "lists.h"
 #include "defines.h"
 #include "array.h"
 
@@ -35,7 +36,9 @@ typedef struct _CHANNEL
 	char topic_who[CLIENT_NICK_LEN];/* Nickname of user that set topic */
 #endif
 	char key[CLIENT_PASS_LEN];	/* Channel key ("password", mode "k" ) */
-	long maxusers;			/* Maximum number of members (mode "l") */
+	unsigned long maxusers;		/* Maximum number of members (mode "l") */
+	struct list_head list_bans;	/* list head of banned users */
+	struct list_head list_invites;	/* list head of invited users */
 } CHANNEL;
 
 typedef struct _CLIENT2CHAN
@@ -53,6 +56,8 @@ typedef POINTER CL2CHAN;
 
 #endif
 
+GLOBAL struct list_head *Channel_GetListBans PARAMS((CHANNEL *c));
+GLOBAL struct list_head *Channel_GetListInvites PARAMS((CHANNEL *c));
 
 GLOBAL void Channel_Init PARAMS(( void ));
 GLOBAL void Channel_InitPredefined PARAMS((  void ));
@@ -65,21 +70,20 @@ GLOBAL void Channel_Quit PARAMS(( CLIENT *Client, char *Reason ));
 
 GLOBAL void Channel_Kick PARAMS((  CLIENT *Client, CLIENT *Origin, char *Name, char *Reason ));
 
-GLOBAL long Channel_Count PARAMS(( void ));
-GLOBAL long Channel_MemberCount PARAMS(( CHANNEL *Chan ));
+GLOBAL unsigned long Channel_Count PARAMS(( void ));
+GLOBAL unsigned long Channel_MemberCount PARAMS(( CHANNEL *Chan ));
 GLOBAL int Channel_CountForUser PARAMS(( CLIENT *Client ));
-GLOBAL int Channel_PCount PARAMS(( void ));
 
-GLOBAL char *Channel_Name PARAMS(( CHANNEL *Chan ));
+GLOBAL const char *Channel_Name PARAMS(( const CHANNEL *Chan ));
 GLOBAL char *Channel_Modes PARAMS(( CHANNEL *Chan ));
 GLOBAL char *Channel_Topic PARAMS(( CHANNEL *Chan ));
 GLOBAL char *Channel_Key PARAMS(( CHANNEL *Chan ));
-GLOBAL long Channel_MaxUsers PARAMS(( CHANNEL *Chan ));
+GLOBAL unsigned long Channel_MaxUsers PARAMS(( CHANNEL *Chan ));
 
 GLOBAL void Channel_SetTopic PARAMS(( CHANNEL *Chan, CLIENT *Client, char *Topic ));
 GLOBAL void Channel_SetModes PARAMS(( CHANNEL *Chan, char *Modes ));
 GLOBAL void Channel_SetKey PARAMS(( CHANNEL *Chan, char *Key ));
-GLOBAL void Channel_SetMaxUsers PARAMS(( CHANNEL *Chan, long Count ));
+GLOBAL void Channel_SetMaxUsers PARAMS(( CHANNEL *Chan, unsigned long Count ));
 
 GLOBAL CHANNEL *Channel_Search PARAMS(( char *Name ));
 
@@ -94,7 +98,7 @@ GLOBAL CL2CHAN *Channel_NextChannelOf PARAMS(( CLIENT *Client, CL2CHAN *Cl2Chan
 GLOBAL CLIENT *Channel_GetClient PARAMS(( CL2CHAN *Cl2Chan ));
 GLOBAL CHANNEL *Channel_GetChannel PARAMS(( CL2CHAN *Cl2Chan ));
 
-GLOBAL bool Channel_IsValidName PARAMS(( char *Name ));
+GLOBAL bool Channel_IsValidName PARAMS(( const char *Name ));
 
 GLOBAL bool Channel_ModeAdd PARAMS(( CHANNEL *Chan, char Mode ));
 GLOBAL bool Channel_ModeDel PARAMS(( CHANNEL *Chan, char Mode ));
@@ -114,8 +118,10 @@ GLOBAL unsigned int Channel_TopicTime PARAMS(( CHANNEL *Chan ));
 GLOBAL char *Channel_TopicWho PARAMS(( CHANNEL *Chan ));
 #endif
 
+GLOBAL bool Channel_AddInvite PARAMS((CHANNEL *c, const char *Mask, bool OnlyOnce ));
+GLOBAL bool Channel_AddBan PARAMS((CHANNEL *c, const char *Mask ));
 
+GLOBAL bool Channel_ShowBans PARAMS((CLIENT *client, CHANNEL *c));
+GLOBAL bool Channel_ShowInvites PARAMS((CLIENT *client, CHANNEL *c));
 #endif
-
-
 /* -eof- */
