@@ -17,7 +17,7 @@
 
 #include "portab.h"
 
-static char UNUSED id[] = "$Id: client.c,v 1.91 2006/04/23 10:37:27 fw Exp $";
+static char UNUSED id[] = "$Id: client.c,v 1.91.2.2 2007/04/03 22:08:52 fw Exp $";
 
 #include "imp.h"
 #include <assert.h>
@@ -57,8 +57,8 @@ static WHOWAS My_Whowas[MAX_WHOWAS];
 static int Last_Whowas = -1;
 
 
-static long Count PARAMS(( CLIENT_TYPE Type ));
-static long MyCount PARAMS(( CLIENT_TYPE Type ));
+static unsigned long Count PARAMS(( CLIENT_TYPE Type ));
+static unsigned long MyCount PARAMS(( CLIENT_TYPE Type ));
 
 static CLIENT *New_Client_Struct PARAMS(( void ));
 static void Generate_MyToken PARAMS(( CLIENT *Client ));
@@ -68,10 +68,6 @@ static CLIENT *Init_New_Client PARAMS((CONN_ID Idx, CLIENT *Introducer,
  CLIENT *TopServer, int Type, char *ID, char *User, char *Hostname,
  char *Info, int Hops, int Token, char *Modes, bool Idented));
 
-#ifndef Client_DestroyNow
-GLOBAL void Client_DestroyNow PARAMS((CLIENT *Client ));
-#endif
-
 
 long Max_Users = 0, My_Max_Users = 0;
 
@@ -211,8 +207,8 @@ Init_New_Client(CONN_ID Idx, CLIENT *Introducer, CLIENT *TopServer,
 	if( Modes ) Client_SetModes( client, Modes );
 	if( Type == CLIENT_SERVER ) Generate_MyToken( client );
 
-	/* ist der User away? */
-	if( strchr( client->modes, 'a' )) strlcpy( client->away, DEFAULT_AWAY_MSG, sizeof( client->away ));
+	if( strchr( client->modes, 'a' ))
+		strlcpy( client->away, DEFAULT_AWAY_MSG, sizeof( client->away ));
 
 	/* Verketten */
 	client->next = (POINTER *)My_Clients;
@@ -336,43 +332,14 @@ Client_Destroy( CLIENT *Client, char *LogMsg, char *FwdMsg, bool SendQuit )
 } /* Client_Destroy */
 
 
-GLOBAL void
-Client_DestroyNow( CLIENT *Client )
-{
-	/* Destroy client structure immediately. This function is only
-	 * intended for the connection layer to remove client structures
-	 * of connections that can't be established! */
-
-	CLIENT *last, *c;
-
-	assert( Client != NULL );
-
-	last = NULL;
-	c = My_Clients;
-	while( c )
-	{
-		if( c == Client )
-		{
-			/* Wir haben den Client gefunden: entfernen */
-			if( last ) last->next = c->next;
-			else My_Clients = (CLIENT *)c->next;
-			free( c );
-			break;
-		}
-		last = c;
-		c = (CLIENT *)c->next;
-	}
-} /* Client_DestroyNow */
-
-
 GLOBAL void
 Client_SetHostname( CLIENT *Client, char *Hostname )
 {
 	/* Hostname eines Clients setzen */
-	
+
 	assert( Client != NULL );
 	assert( Hostname != NULL );
-	
+
 	strlcpy( Client->host, Hostname, sizeof( Client->host ));
 } /* Client_SetHostname */
 
@@ -399,7 +366,7 @@ Client_SetUser( CLIENT *Client, char *User, bool Idented )
 
 	assert( Client != NULL );
 	assert( User != NULL );
-	
+
 	if( Idented ) strlcpy( Client->user, User, sizeof( Client->user ));
 	else
 	{
@@ -416,7 +383,7 @@ Client_SetInfo( CLIENT *Client, char *Info )
 
 	assert( Client != NULL );
 	assert( Info != NULL );
-	
+
 	strlcpy( Client->info, Info, sizeof( Client->info ));
 } /* Client_SetInfo */
 
@@ -452,7 +419,7 @@ Client_SetPassword( CLIENT *Client, char *Pwd )
 
 	assert( Client != NULL );
 	assert( Pwd != NULL );
-	
+
 	strlcpy( Client->pwd, Pwd, sizeof( Client->pwd ));
 } /* Client_SetPassword */
 
@@ -522,7 +489,7 @@ Client_ModeAdd( CLIENT *Client, char Mode )
 	 */
 
 	char x[2];
-	
+
 	assert( Client != NULL );
 
 	x[0] = Mode; x[1] = '\0';
@@ -661,8 +628,7 @@ GLOBAL char *
 Client_User( CLIENT *Client )
 {
 	assert( Client != NULL );
-	if( Client->user[0] ) return Client->user;
-	else return "~";
+	return Client->user[0] ? Client->user : "~";
 } /* Client_User */
 
 
@@ -734,11 +700,13 @@ GLOBAL CLIENT *
 Client_NextHop( CLIENT *Client )
 {
 	CLIENT *c;
-	
+
 	assert( Client != NULL );
 
 	c = Client;
-	while( c->introducer && ( c->introducer != c ) && ( c->introducer != This_Server )) c = c->introducer;
+	while( c->introducer && ( c->introducer != c ) && ( c->introducer != This_Server ))
+		c = c->introducer;
+
 	return c;
 } /* Client_NextHop */
 
@@ -750,7 +718,7 @@ Client_Mask( CLIENT *Client )
 	 * Prefixe benoetigt wird. */
 
 	assert( Client != NULL );
-	
+
 	if( Client->type == CLIENT_SERVER ) return Client->id;
 
 	snprintf( GetID_Buffer, GETID_LEN, "%s!%s@%s", Client->id, Client->user, Client->host );
@@ -795,12 +763,9 @@ Client_Away( CLIENT *Client )
 GLOBAL bool
 Client_CheckNick( CLIENT *Client, char *Nick )
 {
-	/* Nick ueberpruefen */
-
 	assert( Client != NULL );
 	assert( Nick != NULL );
-	
-	/* Nick ungueltig? */
+
 	if( ! Client_IsValidNick( Nick ))
 	{
 		IRC_WriteStrClient( Client, ERR_ERRONEUSNICKNAME_MSG, Client_ID( Client ), Nick );
@@ -913,13 +878,12 @@ Client_MyServiceCount( void )
 } /* Client_MyServiceCount */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Client_MyServerCount( void )
 {
 	CLIENT *c;
-	long cnt;
+	unsigned long cnt = 0;
 
-	cnt = 0;
 	c = My_Clients;
 	while( c )
 	{
@@ -930,13 +894,12 @@ Client_MyServerCount( void )
 } /* Client_MyServerCount */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Client_OperCount( void )
 {
 	CLIENT *c;
-	long cnt;
+	unsigned long cnt = 0;
 
-	cnt = 0;
 	c = My_Clients;
 	while( c )
 	{
@@ -947,19 +910,19 @@ Client_OperCount( void )
 } /* Client_OperCount */
 
 
-GLOBAL long
+GLOBAL unsigned long
 Client_UnknownCount( void )
 {
 	CLIENT *c;
-	long cnt;
+	unsigned long cnt = 0;
 
-	cnt = 0;
 	c = My_Clients;
 	while( c )
 	{
 		if( c && ( c->type != CLIENT_USER ) && ( c->type != CLIENT_SERVICE ) && ( c->type != CLIENT_SERVER )) cnt++;
 		c = (CLIENT *)c->next;
 	}
+
 	return cnt;
 } /* Client_UnknownCount */
 
@@ -979,16 +942,13 @@ Client_MyMaxUserCount( void )
 
 
 GLOBAL bool
-Client_IsValidNick( char *Nick )
+Client_IsValidNick( const char *Nick )
 {
-	/* Ist der Nick gueltig? */
+	const char *ptr;
+	static const char goodchars[] = ";0123456789-";
 
-	char *ptr, goodchars[20];
-	
 	assert( Nick != NULL );
 
-	strcpy( goodchars, ";0123456789-" );
-
 	if( Nick[0] == '#' ) return false;
 	if( strchr( goodchars, Nick[0] )) return false;
 	if( strlen( Nick ) >= CLIENT_NICK_LEN ) return false;
@@ -996,11 +956,11 @@ Client_IsValidNick( char *Nick )
 	ptr = Nick;
 	while( *ptr )
 	{
-		if(( *ptr < 'A' ) && ( ! strchr( goodchars, *ptr ))) return false;
-		if(( *ptr > '}' ) && ( ! strchr( goodchars, *ptr ))) return false;
+		if (( *ptr < 'A' ) && ( ! strchr( goodchars, *ptr ))) return false;
+		if ( *ptr > '}' ) return false;
 		ptr++;
 	}
-	
+
 	return true;
 } /* Client_IsValidNick */
 
@@ -1037,13 +997,12 @@ Client_StartTime(CLIENT *Client)
 } /* Client_Uptime */
 
 
-static long
+static unsigned long
 Count( CLIENT_TYPE Type )
 {
 	CLIENT *c;
-	long cnt;
+	unsigned long cnt = 0;
 
-	cnt = 0;
 	c = My_Clients;
 	while( c )
 	{
@@ -1054,13 +1013,12 @@ Count( CLIENT_TYPE Type )
 } /* Count */
 
 
-static long
+static unsigned long
 MyCount( CLIENT_TYPE Type )
 {
 	CLIENT *c;
-	long cnt;
+	unsigned long cnt = 0;
 
-	cnt = 0;
 	c = My_Clients;
 	while( c )
 	{
@@ -1075,9 +1033,9 @@ static CLIENT *
 New_Client_Struct( void )
 {
 	/* Neue CLIENT-Struktur pre-initialisieren */
-	
+
 	CLIENT *c;
-	
+
 	c = (CLIENT *)malloc( sizeof( CLIENT ));
 	if( ! c )
 	{
@@ -1130,7 +1088,7 @@ Adjust_Counters( CLIENT *Client )
 	assert( Client != NULL );
 
 	if( Client->type != CLIENT_USER ) return;
-	
+
 	if( Client->conn_id != NONE )
 	{
 		/* Local connection */
@@ -1153,7 +1111,7 @@ Client_RegisterWhowas( CLIENT *Client )
 {
 	int slot;
 	time_t now;
-	
+
 	assert( Client != NULL );
 
 	now = time(NULL);
@@ -1167,7 +1125,7 @@ Client_RegisterWhowas( CLIENT *Client )
 #ifdef DEBUG
 	Log( LOG_DEBUG, "Saving WHOWAS information to slot %d ...", slot );
 #endif
-	
+
 	My_Whowas[slot].time = now;
 	strlcpy( My_Whowas[slot].id, Client_ID( Client ),
 		 sizeof( My_Whowas[slot].id ));
@@ -1179,7 +1137,7 @@ Client_RegisterWhowas( CLIENT *Client )
 		 sizeof( My_Whowas[slot].info ));
 	strlcpy( My_Whowas[slot].server, Client_ID( Client_Introducer( Client )),
 		 sizeof( My_Whowas[slot].server ));
-	
+
 	Last_Whowas = slot;
 } /* Client_RegisterWhowas */
 
