@@ -8,7 +8,7 @@
  * (at your option) any later version.
  * Please read the file COPYING, README and AUTHORS for more information.
  *
- * $Id: client.h,v 1.42 2006/04/23 10:37:27 fw Exp $
+ * $Id: client.h,v 1.42.2.3 2007/04/03 22:08:52 fw Exp $
  *
  * Client management (header)
  */
@@ -23,10 +23,9 @@
 #define CLIENT_GOTNICK 4		/* client did send NICK */
 #define CLIENT_GOTUSER 8		/* client did send USER */
 #define CLIENT_USER 16			/* client is an IRC user */
-#define CLIENT_UNKNOWNSERVER 32		/* unregistered server connection */
-#define CLIENT_GOTPASSSERVER 64		/* client did send PASS in "server style" */
-#define CLIENT_SERVER 128		/* client is a server */
-#define CLIENT_SERVICE 256		/* client is a service */
+#define CLIENT_SERVER 32		/* client is a server */
+#define CLIENT_SERVICE 64		/* client is a service */
+#define CLIENT_UNKNOWNSERVER 128	/* unregistered server connection */
 
 #define CLIENT_TYPE int
 
@@ -81,9 +80,6 @@ GLOBAL CLIENT *Client_NewRemoteServer PARAMS(( CLIENT *Introducer, char *Hostnam
 GLOBAL CLIENT *Client_NewRemoteUser PARAMS(( CLIENT *Introducer, char *Nick, int Hops, char *User, char *Hostname, int Token, char *Modes, char *Info, bool Idented ));
 
 GLOBAL void Client_Destroy PARAMS(( CLIENT *Client, char *LogMsg, char *FwdMsg, bool SendQuit ));
-#ifdef CONN_MODULE
-GLOBAL void Client_DestroyNow PARAMS(( CLIENT *Client ));
-#endif
 
 GLOBAL CLIENT *Client_ThisServer PARAMS(( void ));
 
@@ -138,15 +134,15 @@ GLOBAL bool Client_CheckID PARAMS(( CLIENT *Client, char *ID ));
 GLOBAL long Client_UserCount PARAMS(( void ));
 GLOBAL long Client_ServiceCount PARAMS(( void ));
 GLOBAL long Client_ServerCount PARAMS(( void ));
-GLOBAL long Client_OperCount PARAMS(( void ));
-GLOBAL long Client_UnknownCount PARAMS(( void ));
+GLOBAL unsigned long Client_OperCount PARAMS(( void ));
+GLOBAL unsigned long Client_UnknownCount PARAMS(( void ));
 GLOBAL long Client_MyUserCount PARAMS(( void ));
 GLOBAL long Client_MyServiceCount PARAMS(( void ));
-GLOBAL long Client_MyServerCount PARAMS(( void ));
+GLOBAL unsigned long Client_MyServerCount PARAMS(( void ));
 GLOBAL long Client_MaxUserCount PARAMS((  void ));
 GLOBAL long Client_MyMaxUserCount PARAMS((  void ));
 
-GLOBAL bool Client_IsValidNick PARAMS(( char *Nick ));
+GLOBAL bool Client_IsValidNick PARAMS(( const char *Nick ));
 
 GLOBAL WHOWAS *Client_GetWhowas PARAMS(( void ));
 GLOBAL int Client_GetLastWhowasIndex PARAMS(( void ));
