@@ -14,7 +14,7 @@
 
 #include "portab.h"
 
-static char UNUSED id[] = "$Id: conf.c,v 1.92 2006/07/23 16:42:45 alex Exp $";
+static char UNUSED id[] = "$Id: conf.c,v 1.92.2.4 2007/04/03 22:08:52 fw Exp $";
 
 #include "imp.h"
 #include <assert.h>
@@ -146,6 +146,9 @@ Conf_Rehash( void )
 	Set_Defaults( false );
 	Read_Config( );
 	Validate_Config(false, true);
+
+	/* Update CLIENT structure of local server */
+	Client_SetInfo(Client_ThisServer(), Conf_ServerInfo);
 } /* Config_Rehash */
 
 
@@ -199,15 +202,16 @@ Conf_Test( void )
 	printf( "  PingTimeout = %d\n", Conf_PingTimeout );
 	printf( "  PongTimeout = %d\n", Conf_PongTimeout );
 	printf( "  ConnectRetry = %d\n", Conf_ConnectRetry );
-	printf( "  OperCanUseMode = %s\n", Conf_OperCanMode == true? "yes" : "no" );
+	printf( "  OperCanUseMode = %s\n", Conf_OperCanMode == true ? "yes" : "no" );
 	printf( "  OperServerMode = %s\n", Conf_OperServerMode == true? "yes" : "no" );
+	printf( "  PredefChannelsOnly = %s\n", Conf_PredefChannelsOnly == true ? "yes" : "no" );
 	printf( "  MaxConnections = %ld\n", Conf_MaxConnections>0 ? Conf_MaxConnections : -1);
 	printf( "  MaxConnectionsIP = %d\n", Conf_MaxConnectionsIP>0 ? Conf_MaxConnectionsIP : -1);
 	printf( "  MaxJoins = %d\n\n", Conf_MaxJoins>0 ? Conf_MaxJoins : -1);
 
 	for( i = 0; i < Conf_Oper_Count; i++ ) {
 		if( ! Conf_Oper[i].name[0] ) continue;
-		
+
 		/* Valid "Operator" section */
 		puts( "[OPERATOR]" );
 		printf( "  Name = %s\n", Conf_Oper[i].name );
@@ -218,7 +222,7 @@ Conf_Test( void )
 
 	for( i = 0; i < MAX_SERVERS; i++ ) {
 		if( ! Conf_Server[i].name[0] ) continue;
-		
+
 		/* Valid "Server" section */
 		puts( "[SERVER]" );
 		printf( "  Name = %s\n", Conf_Server[i].name );
@@ -231,16 +235,18 @@ Conf_Test( void )
 
 	for( i = 0; i < Conf_Channel_Count; i++ ) {
 		if( ! Conf_Channel[i].name[0] ) continue;
-		
+
 		/* Valid "Channel" section */
 		puts( "[CHANNEL]" );
 		printf( "  Name = %s\n", Conf_Channel[i].name );
 		printf( "  Modes = %s\n", Conf_Channel[i].modes );
+		printf( "  Key = %s\n", Conf_Channel[i].key );
+		printf( "  MaxUsers = %lu\n", Conf_Channel[i].maxusers );
 
 		topic = (char*)array_start(&Conf_Channel[i].topic);
 		printf( "  Topic = %s\n\n", topic ? topic : "");
 	}
-	
+
 	return 0;
 } /* Conf_Test */
 
@@ -268,14 +274,14 @@ Conf_UnsetServer( CONN_ID Idx )
 			Init_Server_Struct( &Conf_Server[i] );
 		} else {
 			/* Set time for next connect attempt */
- 			t = time(NULL);
- 			if (Conf_Server[i].lasttry < t - Conf_ConnectRetry) {
- 				/* The connection has been "long", so we don't
- 				 * require the next attempt to be delayed. */
- 				Conf_Server[i].lasttry =
- 					t - Conf_ConnectRetry + RECONNECT_DELAY;
- 			} else
- 				Conf_Server[i].lasttry = t;
+			t = time(NULL);
+			if (Conf_Server[i].lasttry < t - Conf_ConnectRetry) {
+				/* The connection has been "long", so we don't
+				 * require the next attempt to be delayed. */
+				Conf_Server[i].lasttry =
+					t - Conf_ConnectRetry + RECONNECT_DELAY;
+			} else
+				Conf_Server[i].lasttry = t;
 		}
 	}
 } /* Conf_UnsetServer */
@@ -297,9 +303,9 @@ GLOBAL int
 Conf_GetServer( CONN_ID Idx )
 {
 	/* Get index of server in configuration structure */
-	
+
 	int i = 0;
-	
+
 	assert( Idx > NONE );
 
 	for( i = 0; i < MAX_SERVERS; i++ ) {
@@ -377,7 +383,7 @@ Conf_AddServer( char *Name, UINT16 Port, char *Host, char *MyPwd, char *PeerPwd
 	strlcpy( Conf_Server[i].pwd_in, PeerPwd, sizeof( Conf_Server[i].pwd_in ));
 	Conf_Server[i].port = Port;
 	Conf_Server[i].flags = CONF_SFLAG_ONCE;
-	
+
 	return true;
 } /* Conf_AddServer */
 
@@ -409,7 +415,7 @@ Set_Defaults( bool InitServers )
 	strcpy( Conf_ListenAddress, "" );
 
 	Conf_UID = Conf_GID = 0;
-	
+
 	Conf_PingTimeout = 120;
 	Conf_PongTimeout = 20;
 
@@ -419,8 +425,9 @@ Set_Defaults( bool InitServers )
 	Conf_Channel_Count = 0;
 
 	Conf_OperCanMode = false;
+	Conf_PredefChannelsOnly = false;
 	Conf_OperServerMode = false;
-	
+
 	Conf_MaxConnections = -1;
 	Conf_MaxConnectionsIP = 5;
 	Conf_MaxJoins = 10;
@@ -550,6 +557,8 @@ Read_Config( void )
 					/* Initialize new channel structure */
 					strcpy( Conf_Channel[Conf_Channel_Count].name, "" );
 					strcpy( Conf_Channel[Conf_Channel_Count].modes, "" );
+					strcpy( Conf_Channel[Conf_Channel_Count].key, "" );
+					Conf_Channel[Conf_Channel_Count].maxusers = 0;
 					array_free(&Conf_Channel[Conf_Channel_Count].topic);
 					Conf_Channel_Count++;
 				}
@@ -750,6 +759,11 @@ Handle_GLOBAL( int Line, char *Var, char *Arg )
 		}
 		return;
 	}
+	if( strcasecmp( Var, "PredefChannelsOnly" ) == 0 ) {
+		/* Should we only allow pre-defined-channels? (i.e. users cannot create their own channels) */
+		Conf_PredefChannelsOnly = Check_ArgIsTrue( Arg );
+		return;
+	}
 	if( strcasecmp( Var, "OperCanUseMode" ) == 0 ) {
 		/* Are IRC operators allowed to use MODE in channels they aren't Op in? */
 		Conf_OperCanMode = Check_ArgIsTrue( Arg );
@@ -912,6 +926,21 @@ Handle_SERVER( int Line, char *Var, char *Arg )
 } /* Handle_SERVER */
 
 
+static bool
+Handle_Channelname(size_t chancount, const char *name)
+{
+	size_t size = sizeof( Conf_Channel[chancount].name );
+	char *dest = Conf_Channel[chancount].name;
+
+	if (*name && *name != '#') {
+		*dest = '#';
+		--size;
+		++dest;
+	}
+	return size > strlcpy(dest, name, size);
+}
+
+
 static void
 Handle_CHANNEL( int Line, char *Var, char *Arg )
 {
@@ -925,9 +954,7 @@ Handle_CHANNEL( int Line, char *Var, char *Arg )
 		chancount = Conf_Channel_Count - 1;
 
 	if( strcasecmp( Var, "Name" ) == 0 ) {
-		/* Name of the channel */
-		len = strlcpy( Conf_Channel[chancount].name, Arg, sizeof( Conf_Channel[chancount].name ));
-		if (len >= sizeof( Conf_Channel[chancount].name ))
+		if (!Handle_Channelname(chancount, Arg))
 			Config_Error_TooLong( Line, Var );
 		return;
 	}
@@ -945,6 +972,22 @@ Handle_CHANNEL( int Line, char *Var, char *Arg )
 		return;
 	}
 
+	if( strcasecmp( Var, "Key" ) == 0 ) {
+		/* Initial Channel Key (mode k) */
+		len = strlcpy(Conf_Channel[chancount].key, Arg, sizeof(Conf_Channel[chancount].key));
+		if (len >= sizeof( Conf_Channel[chancount].key ))
+			Config_Error_TooLong(Line, Var);
+		return;
+	}
+
+	if( strcasecmp( Var, "MaxUsers" ) == 0 ) {
+		/* maximum user limit, mode l */
+		Conf_Channel[chancount].maxusers = (unsigned long) atol(Arg);
+		if (Conf_Channel[chancount].maxusers == 0)
+			Config_Error_NaN(Line, Var);
+		return;
+	}
+
 	Config_Error( LOG_ERR, "%s, line %d (section \"Channel\"): Unknown variable \"%s\"!",
 								NGIRCd_ConfFile, Line, Var );
 } /* Handle_CHANNEL */
@@ -965,7 +1008,7 @@ Validate_Config(bool Configtest, bool Rehash)
 	do {
 		if (*ptr >= 'a' && *ptr <= 'z') continue;
 		if (*ptr >= 'A' && *ptr <= 'Z') continue;
-		if (*ptr >= '1' && *ptr <= '0') continue;
+		if (*ptr >= '0' && *ptr <= '9') continue;
 		if (ptr > Conf_ServerName) {
 			if (*ptr == '.' || *ptr == '-')
 				continue;
