@@ -8,7 +8,7 @@
  * (at your option) any later version.
  * Please read the file COPYING, README and AUTHORS for more information.
  *
- * $Id: conf.h,v 1.40 2006/05/10 21:24:01 alex Exp $
+ * $Id: conf.h,v 1.40.2.2 2007/04/03 22:08:52 fw Exp $
  *
  * Configuration management (header)
  */
@@ -49,6 +49,8 @@ typedef struct _Conf_Channel
 {
 	char name[CHANNEL_NAME_LEN];	/* Name of the channel */
 	char modes[CHANNEL_MODE_LEN];	/* Initial channel modes */
+	char key[CLIENT_PASS_LEN];      /* Channel key ("password", mode "k" ) */
+	unsigned long maxusers;		/* maximum usercount for this channel, mode "l" */
 	array topic;			/* Initial topic */
 } CONF_CHANNEL;
 
@@ -110,6 +112,8 @@ GLOBAL CONF_SERVER Conf_Server[MAX_SERVERS];
 /* Pre-defined channels */
 GLOBAL CONF_CHANNEL Conf_Channel[MAX_DEFCHANNELS];
 GLOBAL unsigned int Conf_Channel_Count;
+/* Pre-defined channels only */
+GLOBAL bool Conf_PredefChannelsOnly;
 
 /* Are IRC operators allowed to always use MODE? */
 GLOBAL bool Conf_OperCanMode;
