@@ -8,7 +8,7 @@
  * (at your option) any later version.
  * Please read the file COPYING, README and AUTHORS for more information.
  *
- * $Id: hash.h,v 1.5 2005/03/19 18:43:48 fw Exp $
+ * $Id: hash.h,v 1.5.4.1 2006/12/02 13:18:22 fw Exp $
  *
  * Hash calculation (header)
  */
@@ -17,8 +17,7 @@
 #ifndef __hash_h__
 #define __hash_h__
 
-
-GLOBAL UINT32 Hash PARAMS((char *String ));
+GLOBAL UINT32 Hash PARAMS((const char *String ));
 
 
 #endif
