@@ -8,13 +8,13 @@
  * (at your option) any later version.
  * Please read the file COPYING, README and AUTHORS for more information.
  *
- * $Id: rendezvous.h,v 1.2 2005/03/19 18:43:49 fw Exp $
+ * $Id: rendezvous.h,v 1.4 2006/05/10 21:24:01 alex Exp $
  *
  * "Rendezvous" functions (Header)
  */
 
 
-#ifdef RENDEZVOUS
+#ifdef ZEROCONF
 
 #ifndef __rdezvous_h__
 #define __rdezvous_h__
@@ -23,7 +23,7 @@
 GLOBAL void Rendezvous_Init( void );
 GLOBAL void Rendezvous_Exit( void );
 
-GLOBAL bool Rendezvous_Register( char *Name, char *Type, unsigned int Port );
+GLOBAL bool Rendezvous_Register( char *Name, char *Type, UINT16 Port );
 
 GLOBAL bool Rendezvous_Unregister( char *Name );
 GLOBAL void Rendezvous_UnregisterListeners( void );
@@ -33,7 +33,7 @@ GLOBAL void Rendezvous_Handler( void );
 
 #endif	/* __rdezvous_h__ */
 
-#endif	/* RENDEZVOUS */
+#endif	/* ZEROCONF */
 
 
 /* -eof- */
